/**
 * 用户企业认证要素
 */
export enum UserCertificationElementEnum {
  /**
   * 企业三要素认证
   */
  Identity3 = 10,
  /**
   * 企业四要素认证
   */
  Identity4 = 20,
}

export const UserCertificationElementEnumText = {
  [UserCertificationElementEnum.Identity3]: '企业三要素',
  [UserCertificationElementEnum.Identity4]: '企业四要素',
};

/**
 *  用户认证通道
 */
export enum UserCertificationChannelEnum {
  /**
   *  人工通道
   */
  Human = 10,
  /**
   * 第三方通道
   */
  ThirdParty = 20,
}

/**
 * 用户认证方式
 */

export enum UserCertificationModeEnumV2 {
  /**
   * 法人认证
   */
  LegalPersonCertification = 10,
  /**
   * 代理人认证
   */
  ProxyPersonCertification = 20,
  /**
   * 后台管理员认证
   */
  AdminCertification = 30,
  /**
   * 法定代表人手机号认证
   */
  LegalPersonPhoneCertification = 40,
  /**
   * 法定代表人银行卡认证
   */
  LegalPersonBankCardCertification = 50,
  /**
   * 法定代表人刷脸认证
   */
  LegalPersonFaceCertification = 60,
  /**
   * 代理人手机号认证
   */
  ProxyPersonPhoneCertification = 70,
  /**
   * 代理人银行卡认证
   */
  ProxyPersonBankCardCertification = 80,
  /**
   *  代理人刷脸认证
   */
  ProxyPersonFaceCertification = 90,
}

export const UserCertificationModeEnumV2Text = {
  [UserCertificationModeEnumV2.LegalPersonCertification]: '法人认证',
  [UserCertificationModeEnumV2.ProxyPersonCertification]: '代理人认证',
  [UserCertificationModeEnumV2.AdminCertification]: '后台管理员认证',
  [UserCertificationModeEnumV2.LegalPersonPhoneCertification]: '法定代表人手机号认证',
  [UserCertificationModeEnumV2.LegalPersonBankCardCertification]: '法定代表人银行卡认证',
  [UserCertificationModeEnumV2.LegalPersonFaceCertification]: '法定代表人刷脸认证',
  [UserCertificationModeEnumV2.ProxyPersonPhoneCertification]: '代理人手机号认证',
  [UserCertificationModeEnumV2.ProxyPersonBankCardCertification]: '代理人银行卡认证',
  [UserCertificationModeEnumV2.ProxyPersonFaceCertification]: '代理人刷脸认证',
};

// function createUserCertificationModeV2SelectItem(
//   element: UserCertificationElementEnum,
//   mode: UserCertificationModeEnumV2
// ) {
//   return [
//     `${element}_${mode}`,
//     `${UserCertificationElementEnumText[element]}+${UserCertificationModeEnumV2Text[mode]}`,
//   ] as const;
// }

// export const UserCertificationModeV2Select = new Map([
//   createUserCertificationModeV2SelectItem(
//     UserCertificationElementEnum.Identity4,
//     UserCertificationModeEnumV2.LegalPersonPhoneCertification
//   ),
//   createUserCertificationModeV2SelectItem(
//     UserCertificationElementEnum.Identity4,
//     UserCertificationModeEnumV2.LegalPersonBankCardCertification
//   ),
//   createUserCertificationModeV2SelectItem(
//     UserCertificationElementEnum.Identity4,
//     UserCertificationModeEnumV2.LegalPersonFaceCertification
//   ),
//   createUserCertificationModeV2SelectItem(
//     UserCertificationElementEnum.Identity3,
//     UserCertificationModeEnumV2.ProxyPersonPhoneCertification
//   ),
//   createUserCertificationModeV2SelectItem(
//     UserCertificationElementEnum.Identity3,
//     UserCertificationModeEnumV2.ProxyPersonBankCardCertification
//   ),
// ]);

export enum UserCertificationModeV2SelectEnum {
  Identity4_LegalPersonPhoneCertification = `${UserCertificationElementEnum.Identity4}_${UserCertificationModeEnumV2.LegalPersonPhoneCertification}`,
  Identity4_LegalPersonBankCardCertification = `${UserCertificationElementEnum.Identity4}_${UserCertificationModeEnumV2.LegalPersonBankCardCertification}`,
  Identity4_LegalPersonFaceCertification = `${UserCertificationElementEnum.Identity4}_${UserCertificationModeEnumV2.LegalPersonFaceCertification}`,
  Identity3_ProxyPersonPhoneCertification = `${UserCertificationElementEnum.Identity3}_${UserCertificationModeEnumV2.ProxyPersonPhoneCertification}`,
  Identity3_ProxyPersonBankCardCertification = `${UserCertificationElementEnum.Identity3}_${UserCertificationModeEnumV2.ProxyPersonBankCardCertification}`,
  Identity3_ProxyPersonFaceCertification = `${UserCertificationElementEnum.Identity3}_${UserCertificationModeEnumV2.ProxyPersonFaceCertification}`,
}

export const UserCertificationModeV2SelectEnumText = {
  [UserCertificationModeV2SelectEnum.Identity4_LegalPersonPhoneCertification]: `${
    UserCertificationElementEnumText[UserCertificationElementEnum.Identity4]
  }+${UserCertificationModeEnumV2Text[UserCertificationModeEnumV2.LegalPersonPhoneCertification]}`,
  [UserCertificationModeV2SelectEnum.Identity4_LegalPersonBankCardCertification]: `${
    UserCertificationElementEnumText[UserCertificationElementEnum.Identity4]
  }+${
    UserCertificationModeEnumV2Text[UserCertificationModeEnumV2.LegalPersonBankCardCertification]
  }`,
  [UserCertificationModeV2SelectEnum.Identity4_LegalPersonFaceCertification]: `${
    UserCertificationElementEnumText[UserCertificationElementEnum.Identity4]
  }+${UserCertificationModeEnumV2Text[UserCertificationModeEnumV2.LegalPersonFaceCertification]}`,
  [UserCertificationModeV2SelectEnum.Identity3_ProxyPersonPhoneCertification]: `${
    UserCertificationElementEnumText[UserCertificationElementEnum.Identity3]
  }+${UserCertificationModeEnumV2Text[UserCertificationModeEnumV2.ProxyPersonPhoneCertification]}`,
  [UserCertificationModeV2SelectEnum.Identity3_ProxyPersonBankCardCertification]: `${
    UserCertificationElementEnumText[UserCertificationElementEnum.Identity3]
  }+${
    UserCertificationModeEnumV2Text[UserCertificationModeEnumV2.ProxyPersonBankCardCertification]
  }`,
  [UserCertificationModeV2SelectEnum.Identity3_ProxyPersonFaceCertification]: `${
    UserCertificationElementEnumText[UserCertificationElementEnum.Identity3]
  }+${UserCertificationModeEnumV2Text[UserCertificationModeEnumV2.ProxyPersonFaceCertification]}`,
};
